@@ -35,13 +35,17 @@ struct json_element {
 	TAILQ_ENTRY(json_element) next;
 	json_t *el;
 };
-TAILQ_HEAD(json_writer_private, json_element);
+TAILQ_HEAD(json_element_list, json_element);
+struct json_writer_private {
+	FILE *fh;
+	struct json_element_list els;
+};
 
 static void
 jansson_start(struct writer *w, const char *tag, const char *descr)
 {
 	struct json_writer_private *p = w->priv;
-	struct json_element *current = TAILQ_LAST(p, json_writer_private);
+	struct json_element *current = TAILQ_LAST(&p->els, json_element_list);
 	struct json_element *new;
 	json_t *exist;
 
@@ -57,7 +61,7 @@ jansson_start(struct writer *w, const char *tag, const char *descr)
 	if (new == NULL) fatal(NULL, NULL);
 	new->el = json_object();
 	json_array_append_new(exist, new->el);
-	TAILQ_INSERT_TAIL(p, new, next);
+	TAILQ_INSERT_TAIL(&p->els, new, next);
 }
 
 static void
@@ -65,7 +69,7 @@ jansson_attr(struct writer *w, const char *tag,
     const char *descr, const char *value)
 {
 	struct json_writer_private *p = w->priv;
-	struct json_element *current = TAILQ_LAST(p, json_writer_private);
+	struct json_element *current = TAILQ_LAST(&p->els, json_element_list);
 	json_t *jvalue;
 	if (value && (!strcmp(value, "yes") || !strcmp(value, "on")))
 		jvalue = json_true();
@@ -80,24 +84,11 @@ static void
 jansson_data(struct writer *w, const char *data)
 {
 	struct json_writer_private *p = w->priv;
-	struct json_element *current = TAILQ_LAST(p, json_writer_private);
+	struct json_element *current = TAILQ_LAST(&p->els, json_element_list);
 	json_object_set_new(current->el, "value",
 	    json_string(data?data:""));
 }
 
-static void
-jansson_end(struct writer *w)
-{
-	struct json_writer_private *p = w->priv;
-	struct json_element *current = TAILQ_LAST(p, json_writer_private);
-	if (current == NULL) {
-		log_warnx("lldpctl", "unbalanced tags");
-		return;
-	}
-	TAILQ_REMOVE(p, current, next);
-	free(current);
-}
-
 /* When an array has only one member, just remove the array. When an object has
  * `value` as the only key, remove the object. Moreover, for an object, move the
  * `name` key outside (inside a new object). This is a recursive function. We
@@ -157,26 +148,49 @@ jansson_cleanup(json_t *el)
 	return el;
 }
 
+static void
+jansson_end(struct writer *w)
+{
+	struct json_writer_private *p = w->priv;
+	struct json_element *current = TAILQ_LAST(&p->els, json_element_list);
+	if (current == NULL) {
+		log_warnx("lldpctl", "unbalanced tags");
+		return;
+	}
+	TAILQ_REMOVE(&p->els, current, next);
+	free(current);
+
+	/* Display current object if last one */
+	if (TAILQ_NEXT(TAILQ_FIRST(&p->els), next) == NULL) {
+		struct json_element *root = TAILQ_FIRST(&p->els);
+		json_t *export = jansson_cleanup(root->el);
+		if (json_dumpf(export,
+			p->fh,
+			JSON_INDENT(2) | JSON_PRESERVE_ORDER) == -1)
+			log_warnx("lldpctl", "unable to output JSON");
+		fprintf(p->fh,"\n");
+		json_decref(export);
+		json_decref(root->el);
+		root->el = json_object();
+		if (root->el == NULL)
+			fatalx("lldpctl", "cannot create JSON root object");
+	}
+}
+
 static void
 jansson_finish(struct writer *w)
 {
 	struct json_writer_private *p = w->priv;
-	if (TAILQ_EMPTY(p)) {
+	if (TAILQ_EMPTY(&p->els)) {
 		log_warnx("lldpctl", "nothing to output");
-	} else if (TAILQ_NEXT(TAILQ_FIRST(p), next) != NULL) {
+	} else if (TAILQ_NEXT(TAILQ_FIRST(&p->els), next) != NULL) {
 		log_warnx("lldpctl", "unbalanced tags");
 		/* memory will leak... */
 	} else {
-		struct json_element *first = TAILQ_FIRST(p);
-		json_t *export = jansson_cleanup(first->el);
-		if (json_dumpf(export,
-			stdout,
-			JSON_INDENT(2) | JSON_PRESERVE_ORDER) == -1)
-			log_warnx("lldpctl", "unable to output JSON");
-		json_decref(first->el);
-		json_decref(export);
-		TAILQ_REMOVE(p, first, next);
-		free(first);
+		struct json_element *root = TAILQ_FIRST(&p->els);
+		json_decref(root->el);
+		TAILQ_REMOVE(&p->els, root, next);
+		free(root);
 	}
 	free(p);
 	free(w);
@@ -192,8 +206,10 @@ jansson_init(FILE *fh)
 	priv = malloc(sizeof(*priv));
 	root = malloc(sizeof(*root));
 	if (priv == NULL || root == NULL) fatal(NULL, NULL);
-	TAILQ_INIT(priv);
-	TAILQ_INSERT_TAIL(priv, root, next);
+
+	priv->fh = fh;
+	TAILQ_INIT(&priv->els);
+	TAILQ_INSERT_TAIL(&priv->els, root, next);
 	root->el = json_object();
 	if (root->el == NULL)
 		fatalx("lldpctl", "cannot create JSON root object");
