@@ -53,7 +53,7 @@ priv_open(char *file)
 	return receive_fd(PRIV_UNPRIVILEGED);
 }
 
-/* Proxy for ethtool ioctl */
+/* Proxy for ethtool ioctl (GSET only) */
 int
 priv_ethtool(char *ifname, void *ethc, size_t length)
 {
@@ -71,6 +71,24 @@ priv_ethtool(char *ifname, void *ethc, size_t length)
 	return rc;
 }
 
+/* Proxy to get permanent MAC address */
+int
+priv_iface_mac(char *ifname, void *mac, size_t length)
+{
+	int rc, len;
+	enum priv_cmd cmd = PRIV_IFACE_MAC;
+	must_write(PRIV_UNPRIVILEGED, &cmd, sizeof(enum priv_cmd));
+	len = strlen(ifname);
+	must_write(PRIV_UNPRIVILEGED, &len, sizeof(int));
+	must_write(PRIV_UNPRIVILEGED, ifname, len);
+	priv_wait();
+	must_read(PRIV_UNPRIVILEGED, &rc, sizeof(int));
+	if (rc != 0)
+		return rc;
+	must_read(PRIV_UNPRIVILEGED, mac, length);
+	return rc;
+}
+
 void
 asroot_open()
 {
@@ -78,9 +96,11 @@ asroot_open()
 		"/proc/sys/net/ipv4/ip_forward",
 		"/proc/net/bonding/[^.][^/]*",
 		"/proc/self/net/bonding/[^.][^/]*",
+#ifdef ENABLE_OLDIES
 		SYSFS_CLASS_NET "[^.][^/]*/brforward",
 		SYSFS_CLASS_NET "[^.][^/]*/brport",
 		SYSFS_CLASS_NET "[^.][^/]*/brif/[^.][^/]*/port_no",
+#endif
 		SYSFS_CLASS_DMI "product_version",
 		SYSFS_CLASS_DMI "product_serial",
 		SYSFS_CLASS_DMI "product_name",
@@ -157,6 +177,40 @@ asroot_ethtool()
 	must_write(PRIV_PRIVILEGED, &ethc, sizeof(struct ethtool_cmd));
 }
 
+void
+asroot_iface_mac()
+{
+	struct ifreq ifr = {};
+	int len, rc, sock = -1;
+	char *ifname;
+	struct ethtool_perm_addr *epaddr;
+
+	must_read(PRIV_PRIVILEGED, &len, sizeof(int));
+	if ((ifname = (char*)malloc(len + 1)) == NULL)
+		fatal("privsep", NULL);
+	must_read(PRIV_PRIVILEGED, ifname, len);
+	ifname[len] = '\0';
+	strlcpy(ifr.ifr_name, ifname, sizeof(ifr.ifr_name));
+	free(ifname);
+
+	if ((epaddr = malloc(sizeof(struct ethtool_perm_addr) + ETHER_ADDR_LEN)) == NULL)
+		fatal("privsep", NULL);
+	epaddr->cmd = ETHTOOL_GPERMADDR;
+	epaddr->size = ETHER_ADDR_LEN;
+	ifr.ifr_data = (caddr_t)epaddr;
+	if (((rc = sock = socket(AF_INET, SOCK_DGRAM, 0)) == -1) ||
+	    (rc = ioctl(sock, SIOCETHTOOL, &ifr)) != 0) {
+		if (sock != -1) close(sock);
+		free(epaddr);
+		must_write(PRIV_PRIVILEGED, &rc, sizeof(int));
+		return;
+	}
+	close(sock);
+	must_write(PRIV_PRIVILEGED, &rc, sizeof(int));
+	must_write(PRIV_PRIVILEGED, epaddr->data, ETHER_ADDR_LEN);
+	free(epaddr);
+}
+
 int
 asroot_iface_init_os(int ifindex, char *name, int *fd)
 {
